# Python Nightscout client

[![PyPi](https://img.shields.io/pypi/v/py_nightscout)](https://pypi.org/project/py-nightscout/)

A simple async python client for accessing data stored in [Nightscout](https://github.com/nightscout/cgm-remote-monitor)
Based on [ps2/python-nightscout](https://github.com/ps2/python-nightscout)

## Example Usage

Checkout the [example.py](example.py) file in the repository.
You can add your Nigthscoult URL and `API_TOKEN` and run this script to start using the library.